@@ -10,7 +10,7 @@ import sys
 
 import structlog
 
-from .source import HTTPError, NetworkErrors
+from .httpclient import TemporaryError
 
 def _console_msg(event):
   evt = event['event']
@@ -27,7 +27,7 @@ def _console_msg(event):
     msg = evt
 
   if 'name' in event:
-    msg = '%s: %s' % (event['name'], msg)
+    msg = f"{event['name']}: {msg}"
     del event['name']
 
   event['msg'] = msg
@@ -49,11 +49,9 @@ def filter_exc(logger, level, event):
   else:
     exc = exc_info
 
-  if isinstance(exc, HTTPError):
-    if exc.code == 599: # tornado timeout
+  if isinstance(exc, TemporaryError):
+    if exc.code == 599: # network issues
       del event['exc_info']
-  elif isinstance(exc, NetworkErrors):
-    del event['exc_info']
   event['error'] = exc
   return event
 
