@@ -14,13 +14,15 @@ from pathlib import Path
 import contextvars
 import abc
 
-import toml
+import tomli
 import structlog
 
 from .httpclient import session
 from .ctxvars import tries as ctx_tries
 from .ctxvars import proxy as ctx_proxy
 from .ctxvars import user_agent as ctx_ua
+from .ctxvars import httptoken as ctx_httpt
+from .ctxvars import verify_cert as ctx_verify_cert
 
 logger = structlog.get_logger(logger_name=__name__)
 
@@ -53,9 +55,9 @@ class KeyManager:
   ) -> None:
     if file is not None:
       try:
-        with file.open() as f:
-          keys = toml.load(f)['keys']
-      except (OSError, toml.TomlDecodeError) as e:
+        with file.open('rb') as f:
+          keys = tomli.load(f)['keys']
+      except (OSError, tomli.TOMLDecodeError) as e:
         raise FileLoadError('keyfile', str(file), e)
     else:
       keys = {}
@@ -65,6 +67,28 @@ class KeyManager:
     '''Get the named key (token) in the keyfile.'''
     return self.keys.get(name)
 
+class EntryWaiter:
+  def __init__(self) -> None:
+    self._waiting: Dict[str, asyncio.Future] = {}
+
+  async def wait(self, name: str) -> str:
+    '''Wait on the ``name`` entry and return its result (the version string)'''
+    fu = self._waiting.get(name)
+    if fu is None:
+      fu = asyncio.Future()
+      self._waiting[name] = fu
+    return await fu
+
+  def set_result(self, name: str, value: str) -> None:
+    fu = self._waiting.get(name)
+    if fu is not None:
+      fu.set_result(value)
+
+  def set_exception(self, name: str, e: Exception) -> None:
+    fu = self._waiting.get(name)
+    if fu is not None:
+      fu.set_exception(e)
+
 class RawResult(NamedTuple):
   '''The unprocessed result from a check.'''
   name: str
@@ -224,6 +248,14 @@ class FunctionWorker(BaseWorker):
     ua = entry.get('user_agent', None)
     if ua is not None:
       ctx_ua.set(ua)
+    httpt = entry.get('httptoken', None)
+    if httpt is None:
+      httpt = self.keymanager.get_key('httptoken_'+name)
+    if httpt is not None:
+      ctx_httpt.set(httpt)
+    verify_cert = entry.get('verify_cert', None)
+    if verify_cert is not None:
+      ctx_verify_cert.set(verify_cert)
 
     try:
       async with self.task_sem:
